Exception: JobManager::Application::ComposedError

Inherits:
Error
  • Object
show all
Defined in:
lib/jobmanager/application.rb

Overview

A simple exception class that repackages an existing exception. This class often catches exceptions raised by other libraries, and repackages them, adding additional trace (via the msg parameter).

Instance Method Summary collapse

Constructor Details

#initialize(msg, contained_exception, backtrace = caller()) ⇒ ComposedError

Returns a new instance of ComposedError.



48
49
50
51
52
53
54
# File 'lib/jobmanager/application.rb', line 48

def initialize(msg, contained_exception, backtrace = caller())
  @msg = msg
  @contained_exception = contained_exception
  
  super(msg)
  set_backtrace(backtrace)
end

Instance Method Details

#contained_exceptionObject



56
57
58
# File 'lib/jobmanager/application.rb', line 56

def contained_exception()
  return @contained_exception
end